@@ -203,6 +203,22 @@ class PackageManagerApt(PackageManagerBase):
                 '%s: %s' % (type(e).__name__, format(e))
             )
 
+    def get_error_details(self) -> str:
+        """
+        Provide further error details
+
+        Read the debootstrap log if available
+
+        :rtype: str
+        """
+        debootstrap_log_file = os.path.join(
+            self.root_dir, 'debootstrap/debootstrap.log'
+        )
+        if os.path.exists(debootstrap_log_file):
+            with open(debootstrap_log_file) as log_fd:
+                return log_fd.read() or 'logfile is empty'
+        return f'logfile {debootstrap_log_file!r} does not exist'
+
     def post_process_install_requests_bootstrap(
         self, root_bind: RootBind = None
     ) -> None:
@@ -298,15 +314,19 @@ class PackageManagerApt(PackageManagerBase):
         )
         if force:
             # force deleting debs only worked well for me when ignoring
-            # the pre-inst and pre-remove codings. I don't know why this
+            # the pre/post-inst and pre/post-remove codings. No idea why it
             # ends in so many conflicts but if you want to force get rid
             # of stuff this was the only way I could come up with. There
             # are still cases when it does not work depending on the many
             # code that runs on deleting
             for package in delete_items:
-                delete_pattern = \
+                pre_delete_pattern = \
                     f'{self.root_dir}/var/lib/dpkg/info/{package}*.pre*'
-                for delete_file in glob.iglob(delete_pattern):
+                post_delete_pattern = \
+                    f'{self.root_dir}/var/lib/dpkg/info/{package}*.post*'
+                for delete_file in glob.iglob(pre_delete_pattern):
+                    Path.wipe(delete_file)
+                for delete_file in glob.iglob(post_delete_pattern):
                     Path.wipe(delete_file)
 
             apt_get_command = ['chroot', self.root_dir, 'dpkg']
