@@ -34,7 +34,7 @@ class TestDiskBuilder:
         self._caplog = caplog
 
     @patch('os.path.exists')
-    def setup(self, mock_DiskBuilder, mock_exists):
+    def setup(self, mock_exists):
         Defaults.set_platform_name('x86_64')
 
         def side_effect(filename):
@@ -203,9 +203,16 @@ class TestDiskBuilder:
         self.disk_builder.build_type_name = 'oem'
         self.disk_builder.image_format = None
 
+    @patch('os.path.exists')
+    def setup_method(self, cls, mock_exists):
+        self.setup()
+
     def teardown(self):
         sys.argv = argv_kiwi_tests
 
+    def teardown_method(self, cls):
+        self.teardown()
+
     def test_setup_warn_no_initrd_support(self):
         self.boot_image_task.has_initrd_support = Mock(
             return_value=False
@@ -469,8 +476,12 @@ class TestDiskBuilder:
                 'prep_device': '/dev/prep-device'
             }
         )
-        self.setup.script_exists.assert_called_once_with('disk.sh')
+        assert self.setup.script_exists.call_args_list == [
+            call('pre_disk_sync.sh'),
+            call('disk.sh')
+        ]
         disk_system.import_description.assert_called_once_with()
+        disk_system.call_pre_disk_script.assert_called_once_with()
         disk_system.call_disk_script.assert_called_once_with()
         self.setup.call_edit_boot_config_script.assert_called_once_with(
             'btrfs', 1
@@ -481,23 +492,17 @@ class TestDiskBuilder:
             '/dev/boot-device'
         )
         self.boot_image_task.prepare.assert_called_once_with()
-        call = filesystem.create_on_device.call_args_list[0]
         assert filesystem.create_on_device.call_args_list[0] == \
             call(label='EFI')
-        call = filesystem.create_on_device.call_args_list[1]
         assert filesystem.create_on_device.call_args_list[1] == \
             call(label='BOOT')
-        call = filesystem.create_on_device.call_args_list[2]
         assert filesystem.create_on_device.call_args_list[2] == \
             call(label='ROOT')
 
-        call = filesystem.sync_data.call_args_list[0]
         assert filesystem.sync_data.call_args_list[0] == \
             call()
-        call = filesystem.sync_data.call_args_list[1]
         assert filesystem.sync_data.call_args_list[1] == \
             call(['efi/*'])
-        call = filesystem.sync_data.call_args_list[2]
         assert filesystem.sync_data.call_args_list[2] == \
             call([
                 'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
@@ -557,6 +562,7 @@ class TestDiskBuilder:
     ):
         mock_rand.return_value = 15
         self.disk_builder.root_filesystem_is_overlay = True
+        self.disk_builder.root_filesystem_has_write_partition = False
         self.disk_builder.volume_manager_name = None
         squashfs = Mock()
         mock_squashfs.return_value = squashfs
@@ -566,6 +572,8 @@ class TestDiskBuilder:
         mock_temp.return_value = tempfile
         mock_exists.return_value = True
         self.disk_builder.initrd_system = 'dracut'
+        self.disk.public_partition_id_map = self.id_map
+        self.disk.public_partition_id_map['kiwi_ROPart'] = 1
 
         m_open = mock_open()
         with patch('builtins.open', m_open, create=True):
@@ -720,7 +728,11 @@ class TestDiskBuilder:
         self.disk_builder.volume_manager_name = None
         self.disk_builder.luks = 'passphrase'
         self.disk_setup.need_boot_partition.return_value = False
+        self.disk_builder.root_filesystem_is_overlay = True
+        self.disk_builder.root_filesystem_has_write_partition = False
         self.disk_builder.boot_is_crypto = True
+        self.disk.public_partition_id_map = self.id_map
+        self.disk.public_partition_id_map['kiwi_ROPart'] = 1
 
         with patch('builtins.open'):
             self.disk_builder.create_disk()
