@@ -7,7 +7,7 @@ from kiwi.filesystem.fat16 import FileSystemFat16
 
 class TestFileSystemFat16:
     @patch('os.path.exists')
-    def setup(self, mock_FileSystemFat16, mock_exists):
+    def setup(self, mock_exists):
         mock_exists.return_value = True
         provider = mock.Mock()
         provider.get_device = mock.Mock(
@@ -18,6 +18,10 @@ class TestFileSystemFat16:
             return_value='some-mount-point'
         )
 
+    @patch('os.path.exists')
+    def setup_method(self, cls, mock_exists):
+        self.setup()
+
     @patch('kiwi.filesystem.fat16.Command.run')
     def test_create_on_device(self, mock_command):
         self.fat16.create_on_device('label')
