@@ -37,6 +37,9 @@ class TestPackageManagerApt:
         )
         self.manager = PackageManagerApt(repository)
 
+    def setup_method(self, cls):
+        self.setup()
+
     def test_request_package(self):
         self.manager.request_package('name')
         assert self.manager.package_requests == ['name']
@@ -85,6 +88,33 @@ class TestPackageManagerApt:
         with raises(KiwiDebootstrapError):
             self.manager.process_install_requests_bootstrap(mock_root_bind)
 
+    @patch('kiwi.package_manager.apt.os.path.exists')
+    def test_get_error_details(self, mock_exists):
+        mock_exists.return_value = True
+        with patch('builtins.open', create=True) as mock_open:
+            file_handle = mock_open.return_value.__enter__.return_value
+            file_handle.read.return_value = 'log-data'
+            assert self.manager.get_error_details() == \
+                file_handle.read.return_value
+        mock_open.assert_called_once_with(
+            'root-dir/debootstrap/debootstrap.log'
+        )
+
+    @patch('kiwi.package_manager.apt.os.path.exists')
+    def test_get_error_details_no_log_file(self, mock_exists):
+        mock_exists.return_value = False
+        assert self.manager.get_error_details() == \
+            "logfile 'root-dir/debootstrap/debootstrap.log' does not exist"
+
+    @patch('kiwi.package_manager.apt.os.path.exists')
+    def test_get_error_details_logfile_is_empty(self, mock_exists):
+        mock_exists.return_value = True
+        with patch('builtins.open', create=True) as mock_open:
+            file_handle = mock_open.return_value.__enter__.return_value
+            file_handle.read.return_value = ''
+            assert self.manager.get_error_details() == \
+                'logfile is empty'
+
     @patch('kiwi.command.Command.call')
     @patch('kiwi.package_manager.apt.Path.wipe')
     @patch('kiwi.package_manager.apt.os.path.exists')
@@ -206,10 +236,13 @@ class TestPackageManagerApt:
             ],
             ['env']
         )
-        mock_iglob.assert_called_once_with(
-            'root-dir/var/lib/dpkg/info/vim*.pre*'
-        )
-        mock_Path_wipe.assert_called_once_with('glob-result')
+        mock_iglob.call_args_list == [
+            call('root-dir/var/lib/dpkg/info/vim*.pre*'),
+            call('root-dir/var/lib/dpkg/info/vim*.post*')
+        ]
+        mock_Path_wipe.call_args_list == [
+            call('glob-result'), call('glob-result')
+        ]
 
     @patch('kiwi.command.Command.run')
     def test_post_process_delete_requests(self, mock_run):
