@@ -103,6 +103,9 @@ class TestDiskFormatVmdk:
             self.xml_state, 'root_dir', 'target_dir'
         )
 
+    def setup_method(self, cls):
+        self.setup()
+
     def test_post_init(self):
         self.disk_format.post_init(
             {'option': 'value', 'adapter_type=pvscsi': None}
