@@ -75,9 +75,15 @@ class TestSystemBuildTask:
 
         self.task = SystemBuildTask()
 
+    def setup_method(self, cls):
+        self.setup()
+
     def teardown(self):
         sys.argv = argv_kiwi_tests
 
+    def teardown_method(self, cls):
+        self.teardown()
+
     def _init_command_args(self):
         self.task.command_args = {}
         self.task.command_args['help'] = False
